==> audit_1.7.13.orig.tar.gz: audit-1.7.13/auparse/famtab.h <==

/* famtab.h --
 * Copyright 2007 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 */

_S(AF_LOCAL,		"local"		)
_S(AF_INET,		"inet"		)
_S(AF_AX25,		"ax25"		)
_S(AF_IPX,		"ipx"		)
_S(AF_APPLETALK,	"appletalk"	)
_S(AF_NETROM,		"netrom"	)
_S(AF_BRIDGE,		"bridge"	)
_S(AF_ATMPVC,		"atmpvc"	)
_S(AF_X25,		"x25"		)
_S(AF_INET6,		"inet6"		)
_S(AF_ROSE,		"rose"		)
_S(AF_DECnet,		"decnet"	)
_S(AF_NETBEUI,		"netbeui"	)
_S(AF_SECURITY,		"security"	)
_S(AF_KEY,		"key"		)
_S(AF_NETLINK,		"netlink"	)
_S(AF_PACKET,		"packet"	)
_S(AF_ASH,		"ash"		)
_S(AF_ECONET,		"econet"	)
_S(AF_ATMSVC,		"atmsvc"	)
_S(AF_SNA,		"sna"		)
_S(AF_IRDA,		"irda"		)
_S(AF_PPPOX,		"pppox"		)
_S(AF_WANPIPE,		"wanpipe"	)
_S(AF_BLUETOOTH,	"bluetooth"	)

==> audit_2.2.2.orig.tar.gz: audit-2.2.2/auparse/famtab.h <==
/* famtab.h --
 * Copyright 2007,2012 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 * Location: include/linux/socket.h
 */

_S(AF_LOCAL,		"local"		)
_S(AF_INET,		"inet"		)
_S(AF_AX25,		"ax25"		)
_S(AF_IPX,		"ipx"		)
_S(AF_APPLETALK,	"appletalk"	)
_S(AF_NETROM,		"netrom"	)
_S(AF_BRIDGE,		"bridge"	)
_S(AF_ATMPVC,		"atmpvc"	)
_S(AF_X25,		"x25"		)
_S(AF_INET6,		"inet6"		)
_S(AF_ROSE,		"rose"		)
_S(AF_DECnet,		"decnet"	)
_S(AF_NETBEUI,		"netbeui"	)
_S(AF_SECURITY,		"security"	)
_S(AF_KEY,		"key"		)
_S(AF_NETLINK,		"netlink"	)
_S(AF_PACKET,		"packet"	)
_S(AF_ASH,		"ash"		)
_S(AF_ECONET,		"econet"	)
_S(AF_ATMSVC,		"atmsvc"	)
_S(AF_RDS,		"rds"		)
_S(AF_SNA,		"sna"		)
_S(AF_IRDA,		"irda"		)
_S(AF_PPPOX,		"pppox"		)
_S(AF_WANPIPE,		"wanpipe"	)
_S(AF_LLC,		"llc"		)
_S(AF_CAN,		"can"		)
_S(AF_TIPC,		"tipc"		)
_S(AF_BLUETOOTH,	"bluetooth"	)
_S(AF_IUCV,		"iucv"		)
_S(AF_RXRPC,		"rxrpc"		)
_S(AF_ISDN,		"isdn"		)
_S(AF_PHONET,		"phonet"	)
_S(AF_IEEE802154,	"ieee802154"	)
_S(37,			"caif"		)
_S(38,			"alg"		)
_S(39,			"nfc"		)
